## 📝 Description

<!-- Provide a clear and concise description of your changes -->

## 🎯 Type of Change

<!-- Mark the relevant option with an 'x' -->

- [ ] 🐛 Bug fix (non-breaking change which fixes an issue)
- [ ] ✨ New feature (non-breaking change which adds functionality)
- [ ] 💥 Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] 📝 Documentation update
- [ ] 🔧 Refactoring (no functional changes)
- [ ] 🎨 Style/formatting changes
- [ ] ⚡ Performance improvement
- [ ] ✅ Test update

## 🔗 Related Issues

<!-- Link to related issues, e.g., "Fixes #123" or "Relates to #456" -->

Closes #

## 📋 Checklist

<!-- Mark completed items with an 'x' -->

- [ ] My code follows the project's style guidelines
- [ ] I have performed a self-review of my code
- [ ] I have commented my code, particularly in hard-to-understand areas
- [ ] I have made corresponding changes to the documentation
- [ ] My changes generate no new warnings
- [ ] I have added tests that prove my fix is effective or that my feature works
- [ ] New and existing unit tests pass locally with my changes
- [ ] I have updated the CHANGELOG.md

## 🧪 Testing

<!-- Describe the tests you ran and how to reproduce them -->

**Test Configuration:**
- OS: 
- Python Version: 
- vogel-model-trainer Version: 

**Test Steps:**
1. 
2. 
3. 

## 📸 Screenshots (if applicable)

<!-- Add screenshots or videos to help explain your changes -->

## 💭 Additional Context

<!-- Add any other context about the pull request here -->

## 📚 Documentation

<!-- If you added new features, explain where users can find documentation -->
- [ ] README.md updated
- [ ] Docstrings added/updated
- [ ] Examples added

---

**Note:** Please ensure you've read our [Contributing Guidelines](CONTRIBUTING.md) before submitting this PR.
